# Release History

## 0.2.1 - 2025-01-05

### Changed

* Improved CI

## 0.2.0 - 2024-04-27

### Added

* Add aarch64 as a target for Linux

### Changed

* Improved typing (see https://github.com/mberk/shin/issues/2, https://github.com/mberk/shin/issues/4)

## 0.1.0 - 2023-11-03

### Changed

* Fix type hint from Sequence to Collection
* Add Rust optimiser
* Handle Mappings as well as Collections
* Only return implied probabilities by default

## 0.0.2 - 2020-04-20

### Changed

* Guard against less than two outcomes

### Fixed

* Handle two outcomes cases (previously caused a division by zero)

## 0.0.1 - 2020-03-24
